@@ -7,9 +7,8 @@
 #include "importmailpluginmanager.h"
 #include "abstractimporter.h"
 #include "importwizard_debug.h"
-
+#include "kcoreaddons_version.h"
 #include <KPluginFactory>
-#include <KPluginLoader>
 #include <KPluginMetaData>
 
 #include <QFileInfo>
@@ -40,8 +39,7 @@ ImportMailPluginManager *ImportMailPluginManager::self()
 
 bool ImportMailPluginManager::initializePluginList()
 {
-    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("importwizard"));
-
+    const QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("importwizard"));
     QVectorIterator<KPluginMetaData> i(plugins);
     i.toBack();
     while (i.hasPrevious()) {
@@ -50,9 +48,8 @@ bool ImportMailPluginManager::initializePluginList()
 
         // 1) get plugin data => name/description etc.
         info.pluginData = createPluginMetaData(data);
-        // 2) look at if plugin is activated
-        info.metaDataFileNameBaseName = QFileInfo(data.fileName()).baseName();
         info.metaDataFileName = data.fileName();
+        info.data = data;
         if (pluginVersion() == data.version()) {
             info.plugin = nullptr;
             mPluginList.push_back(info);
@@ -69,9 +66,8 @@ bool ImportMailPluginManager::initializePluginList()
 
 void ImportMailPluginManager::loadPlugin(ImportMailPluginManagerInfo *item)
 {
-    KPluginLoader pluginLoader(item->metaDataFileName);
-    if (pluginLoader.factory()) {
-        item->plugin = pluginLoader.factory()->create<LibImportWizard::AbstractImporter>(this, QVariantList() << item->metaDataFileNameBaseName);
+    if (auto plugin = KPluginFactory::instantiatePlugin<LibImportWizard::AbstractImporter>(item->data, this, QVariantList() << item->metaDataFileName).plugin) {
+        item->plugin = plugin;
         mPluginDataList.append(item->pluginData);
     }
 }
