@@ -3,8 +3,7 @@
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef IMPORTMAILPLUGINMANAGER_H
-#define IMPORTMAILPLUGINMANAGER_H
+#pragma once
 
 #include <KPluginMetaData>
 #include <QObject>
@@ -34,9 +33,9 @@ public:
     {
     }
 
-    QString metaDataFileNameBaseName;
     QString metaDataFileName;
     PluginUtilData pluginData;
+    KPluginMetaData data;
     LibImportWizard::AbstractImporter *plugin = nullptr;
 };
 
@@ -45,7 +44,7 @@ class ImportMailPluginManager : public QObject
     Q_OBJECT
 public:
     explicit ImportMailPluginManager(QObject *parent = nullptr);
-    ~ImportMailPluginManager();
+    ~ImportMailPluginManager() override;
 
     static ImportMailPluginManager *self();
     bool initializePluginList();
@@ -59,4 +58,3 @@ private:
     QVector<PluginUtilData> mPluginDataList;
 };
 
-#endif // IMPORTMAILPLUGINMANAGER_H
