@@ -5,11 +5,11 @@
 */
 #include "importwizardkernel.h"
 
-#include <AkonadiCore/changerecorder.h>
-#include <AkonadiCore/entitymimetypefiltermodel.h>
-#include <AkonadiCore/entitytreemodel.h>
-#include <AkonadiCore/session.h>
-#include <KIdentityManagement/kidentitymanagement/identitymanager.h>
+#include <Akonadi/ChangeRecorder>
+#include <Akonadi/EntityMimeTypeFilterModel>
+#include <Akonadi/EntityTreeModel>
+#include <Akonadi/Session>
+#include <KIdentityManagement/IdentityManager>
 #include <KSharedConfig>
 #include <MailCommon/FolderCollectionMonitor>
 
