@@ -7,12 +7,12 @@
 #include "abstractdisplayinfo.h"
 
 #include "libimportwizard_debug.h"
-#include <AkonadiCore/Item>
-#include <AkonadiCore/ItemCreateJob>
-#include <AkonadiWidgets/CollectionDialog>
+#include <Akonadi/CollectionDialog>
+#include <Akonadi/Item>
+#include <Akonadi/ItemCreateJob>
 #include <KContacts/Addressee>
+#include <KContacts/ContactGroup>
 #include <KLocalizedString>
-#include <kcontacts/contactgroup.h>
 
 #include <QPointer>
 using namespace LibImportWizard;
