@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "balsasettings.h"
 #include "balsaplugin_debug.h"
-#include <MailTransport/TransportManager>
 #include <MailCommon/MailUtil>
+#include <MailTransport/TransportManager>
 #include <MessageViewer/KXFace>
 
-#include <KIdentityManagement/kidentitymanagement/identity.h>
-#include <KIdentityManagement/kidentitymanagement/signature.h>
+#include <KIdentityManagement/Identity>
+#include <KIdentityManagement/Signature>
 
 #include <KConfig>
 #include <KConfigGroup>
@@ -55,7 +55,7 @@ void BalsaSettings::importSettings()
 
 void BalsaSettings::readAccount(const KConfigGroup &grp, bool autoCheck, int autoDelay)
 {
-    Q_UNUSED(autoDelay);
+    Q_UNUSED(autoDelay)
     const QString type = grp.readEntry(QStringLiteral("Type"));
     bool check = grp.readEntry(QStringLiteral("Check"), false);
     if (type == QLatin1String("LibBalsaMailboxPOP3")) {
@@ -64,8 +64,8 @@ void BalsaSettings::readAccount(const KConfigGroup &grp, bool autoCheck, int aut
         settings.insert(QStringLiteral("Host"), server);
         const QString name = grp.readEntry(QStringLiteral("Name"));
 
-        //const bool apop = grp.readEntry(QStringLiteral("DisableApop"), false);
-        //Q_UNUSED(apop);
+        // const bool apop = grp.readEntry(QStringLiteral("DisableApop"), false);
+        // Q_UNUSED(apop)
         const QString agentIdentifyName = LibImportWizard::AbstractBase::createResource(QStringLiteral("akonadi_pop3_resource"), name, settings);
 
         addCheckMailOnStartup(agentIdentifyName, autoCheck);
@@ -128,7 +128,7 @@ void BalsaSettings::readTransport(const KConfigGroup &grp)
     mt->setHost(server);
 
     const int tlsMode = grp.readEntry(QStringLiteral("TLSMode"), -1);
-    //TODO
+    // TODO
     switch (tlsMode) {
     case 0:
         break;
@@ -150,13 +150,13 @@ void BalsaSettings::readTransport(const KConfigGroup &grp)
         qCDebug(BALSAPLUGIN_LOG) << " unknown ssl value :" << ssl;
     }
 
-    //TODO const QString anonymous = grp.readEntry(QStringLiteral("Anonymous"));
+    // TODO const QString anonymous = grp.readEntry(QStringLiteral("Anonymous"));
 
-    //TODO
-    storeTransport(mt, /*( smtp == defaultSmtp )*/ true);   //FIXME
+    // TODO
+    storeTransport(mt, /*( smtp == defaultSmtp )*/ true); // FIXME
     mHashSmtp.insert(smtp, QString::number(mt->id()));
 
-    //TODO
+    // TODO
     /*
     Server=localhost:25
     Anonymous=false
@@ -183,12 +183,12 @@ void BalsaSettings::readGlobalSettings(const KConfig &config)
 #if 0
         if (messageDisplay.hasKey(QStringLiteral("WordWrap"))) {
             //bool wordWrap = messageDisplay.readEntry(QStringLiteral("WordWrap"), false);
-            //Q_UNUSED(wordWrap);
+            //Q_UNUSED(wordWrap)
             //TODO not implemented in kmail.
         }
         if (messageDisplay.hasKey(QStringLiteral("WordWrapLength"))) {
             const int wordWrapLength = messageDisplay.readEntry(QStringLiteral("WordWrapLength"), -1);
-            Q_UNUSED(wordWrapLength);
+            Q_UNUSED(wordWrapLength)
             //TODO not implemented in kmail
         }
 #endif
