@@ -7,7 +7,7 @@
 #pragma once
 
 #include "abstractsettings.h"
-#include <KIdentityManagement/kidentitymanagement/signature.h>
+#include <KIdentityManagement/Signature>
 #include <QString>
 
 class QDomElement;
@@ -16,7 +16,7 @@ class EvolutionSettings : public AbstractSettings
 {
 public:
     EvolutionSettings();
-    ~EvolutionSettings();
+    ~EvolutionSettings() override;
     void loadAccount(const QString &filename);
     void loadLdap(const QString &filename);
 
