@@ -9,8 +9,8 @@
 
 #include <MailTransport/TransportManager>
 
-#include <KIdentityManagement/kidentitymanagement/identity.h>
-#include <KIdentityManagement/kidentitymanagement/signature.h>
+#include <KIdentityManagement/Identity>
+#include <KIdentityManagement/Signature>
 
 #include "trojitaplugin_debug.h"
 
